tonalanalysistools.ChordClass
=============================

.. abjad-lineage:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass

.. autoclass:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.bass
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.cardinality
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.cardinality_to_extent
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.copy
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.difference
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.extent
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.extent_to_cardinality
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.extent_to_extent_name
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.figured_bass
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.from_selection
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.intersection
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.inversion
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.invert
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.is_transposed_subset
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.is_transposed_superset
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.isdisjoint
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.issubset
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.issuperset
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.item_class
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.markup
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.multiply
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.name
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.new
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.order_by
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.quality_indicator
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.quality_pair
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.root
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.root_string
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.storage_format
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.symmetric_difference
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.transpose
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.union
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__and__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__contains__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__eq__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__ge__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__gt__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__hash__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__iter__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__le__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__len__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__lt__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__ne__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__or__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__repr__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__str__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__sub__
      ~abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__xor__

Bases
-----

- :py:class:`pitchtools.PitchClassSet <abjad.tools.pitchtools.PitchClassSet.PitchClassSet.PitchClassSet>`

- :py:class:`pitchtools.Set <abjad.tools.pitchtools.Set.Set.Set>`

- :py:class:`datastructuretools.TypedFrozenset <abjad.tools.datastructuretools.TypedFrozenset.TypedFrozenset.TypedFrozenset>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.bass
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.cardinality
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.extent
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.figured_bass
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.inversion
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.item_class
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.markup
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.quality_indicator
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.quality_pair
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.root
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.root_string
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.copy
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.difference
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.intersection
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.invert
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.is_transposed_subset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.is_transposed_superset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.isdisjoint
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.issubset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.issuperset
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.multiply
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.new
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.order_by
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.transpose
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.union
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.from_selection
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.cardinality_to_extent
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.extent_to_cardinality
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.extent_to_extent_name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__and__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__contains__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__ge__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__gt__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__iter__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__le__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__len__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__lt__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__or__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__str__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__sub__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.ChordClass.ChordClass.ChordClass.__xor__
   :noindex:
